Index: /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/converter/UIConverterBackendGlobal.cpp	(revision 75319)
@@ -609,7 +609,7 @@
         case UIExtraDataMetaDefs::RuntimeMenuViewActionType_GuestAutoresize:      strResult = "GuestAutoresize"; break;
         case UIExtraDataMetaDefs::RuntimeMenuViewActionType_TakeScreenshot:       strResult = "TakeScreenshot"; break;
-        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_Recording:            strResult = "VideoCapture"; break;
-        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_RecordingSettings:    strResult = "VideoCaptureSettings"; break;
-        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_StartRecording:       strResult = "StartVideoCapture"; break;
+        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_Recording:            strResult = "Recording"; break;
+        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_RecordingSettings:    strResult = "RecordingSettings"; break;
+        case UIExtraDataMetaDefs::RuntimeMenuViewActionType_StartRecording:       strResult = "StartRecording"; break;
         case UIExtraDataMetaDefs::RuntimeMenuViewActionType_VRDEServer:           strResult = "VRDEServer"; break;
         case UIExtraDataMetaDefs::RuntimeMenuViewActionType_MenuBar:              strResult = "MenuBar"; break;
@@ -649,7 +649,7 @@
     keys << "GuestAutoresize";      values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_GuestAutoresize;
     keys << "TakeScreenshot";       values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_TakeScreenshot;
-    keys << "VideoCapture";         values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_Recording;
-    keys << "VideoCaptureSettings"; values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_RecordingSettings;
-    keys << "StartVideoCapture";    values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_StartRecording;
+    keys << "Recording";            values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_Recording;
+    keys << "RecordingSettings";    values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_RecordingSettings;
+    keys << "StartRecording";       values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_StartRecording;
     keys << "VRDEServer";           values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_VRDEServer;
     keys << "MenuBar";              values << UIExtraDataMetaDefs::RuntimeMenuViewActionType_MenuBar;
@@ -1403,5 +1403,5 @@
         case IndicatorType_SharedFolders: strResult = "SharedFolders"; break;
         case IndicatorType_Display:       strResult = "Display"; break;
-        case IndicatorType_Recording:     strResult = "VideoCapture"; break;
+        case IndicatorType_Recording:     strResult = "Recording"; break;
         case IndicatorType_Features:      strResult = "Features"; break;
         case IndicatorType_Mouse:         strResult = "Mouse"; break;
@@ -1430,5 +1430,5 @@
     keys << "SharedFolders"; values << IndicatorType_SharedFolders;
     keys << "Display";       values << IndicatorType_Display;
-    keys << "VideoCapture";  values << IndicatorType_Recording;
+    keys << "Recording";     values << IndicatorType_Recording;
     keys << "Features";      values << IndicatorType_Features;
     keys << "Mouse";         values << IndicatorType_Mouse;
@@ -1455,5 +1455,5 @@
         case IndicatorType_SharedFolders: strResult = QApplication::translate("VBoxGlobal", "Shared Folders", "IndicatorType"); break;
         case IndicatorType_Display:       strResult = QApplication::translate("VBoxGlobal", "Display", "IndicatorType"); break;
-        case IndicatorType_Recording:     strResult = QApplication::translate("VBoxGlobal", "Video Capture", "IndicatorType"); break;
+        case IndicatorType_Recording:     strResult = QApplication::translate("VBoxGlobal", "Recording", "IndicatorType"); break;
         case IndicatorType_Features:      strResult = QApplication::translate("VBoxGlobal", "Features", "IndicatorType"); break;
         case IndicatorType_Mouse:         strResult = QApplication::translate("VBoxGlobal", "Mouse", "IndicatorType"); break;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 75319)
@@ -1083,5 +1083,5 @@
     virtual void retranslateUi() /* override */
     {
-        setName(QApplication::translate("UIActionPool", "Audio/&Video Capture"));
+        setName(QApplication::translate("UIActionPool", "&Recording"));
     }
 };
@@ -1120,12 +1120,12 @@
     virtual QString shortcutExtraDataID() const /* override */
     {
-        return QString("VideoCaptureSettingsDialog");
-    }
-
-    /** Handles translation event. */
-    virtual void retranslateUi() /* override */
-    {
-        setName(QApplication::translate("UIActionPool", "&Video Capture Settings..."));
-        setStatusTip(QApplication::translate("UIActionPool", "Display virtual machine settings window to configure video capture"));
+        return QString("RecordingSettingsDialog");
+    }
+
+    /** Handles translation event. */
+    virtual void retranslateUi() /* override */
+    {
+        setName(QApplication::translate("UIActionPool", "&Recording Settings..."));
+        setStatusTip(QApplication::translate("UIActionPool", "Display virtual machine settings window to configure video/audio recording"));
     }
 };
@@ -1167,12 +1167,12 @@
     virtual QString shortcutExtraDataID() const /* override */
     {
-        return QString("VideoCapture");
-    }
-
-    /** Handles translation event. */
-    virtual void retranslateUi() /* override */
-    {
-        setName(QApplication::translate("UIActionPool", "Audio/&Video Capture"));
-        setStatusTip(QApplication::translate("UIActionPool", "Enable guest display video capture"));
+        return QString("Recording");
+    }
+
+    /** Handles translation event. */
+    virtual void retranslateUi() /* override */
+    {
+        setName(QApplication::translate("UIActionPool", "&Recording"));
+        setStatusTip(QApplication::translate("UIActionPool", "Enable guest video/audio recording"));
     }
 };
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIMainEventListener.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIMainEventListener.h	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIMainEventListener.h	(revision 75319)
@@ -124,5 +124,5 @@
         /** Notifies about VRDE device state change. */
         void sigVRDEChange();
-        /** Notifies about capture state change. */
+        /** Notifies about recording state change. */
         void sigRecordingChange();
         /** Notifies about USB controller state change. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIPopupCenter.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIPopupCenter.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIPopupCenter.cpp	(revision 75319)
@@ -574,8 +574,8 @@
     /* Get machine-name preserving error-info: */
     QString strMachineName(CMachine(comMachine).GetName());
-    alertWithDetails(pParent, "cannotToggleVideoCapture",
+    alertWithDetails(pParent, "cannotToggleRecording",
                      fEnable ?
-                     QApplication::translate("UIMessageCenter", "Failed to enable video capturing for the virtual machine <b>%1</b>.").arg(strMachineName) :
-                     QApplication::translate("UIMessageCenter", "Failed to disable video capturing for the virtual machine <b>%1</b>.").arg(strMachineName),
+                     QApplication::translate("UIMessageCenter", "Failed to enable recording for the virtual machine <b>%1</b>.").arg(strMachineName) :
+                     QApplication::translate("UIMessageCenter", "Failed to disable recording for the virtual machine <b>%1</b>.").arg(strMachineName),
                      UIErrorString::formatErrorInfo(comMachine));
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/details/UIDetailsElements.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/details/UIDetailsElements.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/details/UIDetailsElements.cpp	(revision 75319)
@@ -450,23 +450,23 @@
 
         /* Recording info: */
-        CCaptureSettings captureSettings = machine.GetCaptureSettings();
-        if (captureSettings.GetEnabled())
+        CCaptureSettings comRecordingSettings = machine.GetCaptureSettings();
+        if (comRecordingSettings.GetEnabled())
         {
             /* For now all screens have the same config: */
-            CCaptureScreenSettings captureScreen0Settings = captureSettings.GetScreenSettings(0);
+            CCaptureScreenSettings comRecordingScreen0Settings = comRecordingSettings.GetScreenSettings(0);
 
             /** @todo r=andy Refine these texts (wrt audio and/or video). */
-            table << UITextTableLine(QApplication::translate("UIDetails", "Recording File", "details (display/video capture)"),
-                                     captureScreen0Settings.GetFileName());
-            table << UITextTableLine(QApplication::translate("UIDetails", "Recording Attributes", "details (display/video capture)"),
+            table << UITextTableLine(QApplication::translate("UIDetails", "Recording File", "details (display/recording)"),
+                                     comRecordingScreen0Settings.GetFileName());
+            table << UITextTableLine(QApplication::translate("UIDetails", "Recording Attributes", "details (display/recording)"),
                                      QApplication::translate("UIDetails", "Frame Size: %1x%2, Frame Rate: %3fps, Bit Rate: %4kbps")
-                                         .arg(captureScreen0Settings.GetVideoWidth()).arg(captureScreen0Settings.GetVideoHeight())
-                                         .arg(captureScreen0Settings.GetVideoFPS()).arg(captureScreen0Settings.GetVideoRate()));
+                                         .arg(comRecordingScreen0Settings.GetVideoWidth()).arg(comRecordingScreen0Settings.GetVideoHeight())
+                                         .arg(comRecordingScreen0Settings.GetVideoFPS()).arg(comRecordingScreen0Settings.GetVideoRate()));
         }
         else
         {
             /** @todo r=andy Refine these texts (wrt audio and/or video). */
-            table << UITextTableLine(QApplication::translate("UIDetails", "Recording", "details (display/video capture)"),
-                                     QApplication::translate("UIDetails", "Disabled", "details (display/video capture)"));
+            table << UITextTableLine(QApplication::translate("UIDetails", "Recording", "details (display/recording)"),
+                                     QApplication::translate("UIDetails", "Disabled", "details (display/recording)"));
         }
     }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineLogic.cpp	(revision 75319)
@@ -2104,11 +2104,11 @@
 
     /* Make sure something had changed: */
-    CCaptureSettings recordingSettings = machine().GetCaptureSettings();
-    if (recordingSettings.GetEnabled() == static_cast<BOOL>(fEnabled))
+    CCaptureSettings comRecordingSettings = machine().GetCaptureSettings();
+    if (comRecordingSettings.GetEnabled() == static_cast<BOOL>(fEnabled))
         return;
 
     /* Update recording state: */
-    recordingSettings.SetEnabled(fEnabled);
-    if (!recordingSettings.isOk())
+    comRecordingSettings.SetEnabled(fEnabled);
+    if (!comRecordingSettings.isOk())
     {
         /* Make sure action is updated: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.cpp	(revision 75319)
@@ -724,12 +724,12 @@
 void UISession::sltRecordingChange()
 {
-    CCaptureSettings captureSettings = machine().GetCaptureSettings();
+    CCaptureSettings comRecordingSettings = machine().GetCaptureSettings();
 
     /* Check/Uncheck Capture action depending on feature status: */
     actionPool()->action(UIActionIndexRT_M_View_M_Recording_T_Start)->blockSignals(true);
-    actionPool()->action(UIActionIndexRT_M_View_M_Recording_T_Start)->setChecked(captureSettings.GetEnabled());
+    actionPool()->action(UIActionIndexRT_M_View_M_Recording_T_Start)->setChecked(comRecordingSettings.GetEnabled());
     actionPool()->action(UIActionIndexRT_M_View_M_Recording_T_Start)->blockSignals(false);
 
-    /* Notify listeners about Capture change: */
+    /* Notify listeners about Recording change: */
     emit sigRecordingChange();
 }
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.h	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UISession.h	(revision 75319)
@@ -258,5 +258,5 @@
     /** Updates VRDE Server action state. */
     void updateStatusVRDE() { sltVRDEChange(); }
-    /** Updates Video Capture action state. */
+    /** Updates Recording action state. */
     void updateStatusRecording() { sltRecordingChange(); }
     /** Updates Audio output action state. */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineWindowNormal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineWindowNormal.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineWindowNormal.cpp	(revision 75319)
@@ -219,5 +219,5 @@
         case IndicatorType_SharedFolders: pAction = actionPool()->action(UIActionIndexRT_M_Devices_M_SharedFolders);  break;
         case IndicatorType_Display:       pAction = actionPool()->action(UIActionIndexRT_M_ViewPopup);                break;
-        case IndicatorType_Recording:  pAction = actionPool()->action(UIActionIndexRT_M_View_M_Recording);      break;
+        case IndicatorType_Recording:     pAction = actionPool()->action(UIActionIndexRT_M_View_M_Recording);         break;
         case IndicatorType_Mouse:         pAction = actionPool()->action(UIActionIndexRT_M_Input_M_Mouse);            break;
         case IndicatorType_Keyboard:      pAction = actionPool()->action(UIActionIndexRT_M_Input_M_Keyboard);         break;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/snapshots/UISnapshotDetailsWidget.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/snapshots/UISnapshotDetailsWidget.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/snapshots/UISnapshotDetailsWidget.cpp	(revision 75319)
@@ -1377,8 +1377,8 @@
             {
                 ++iRowCount;
-                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording File", "details (display/video capture)"),
+                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording File", "details (display/recording)"),
                                                          empReport(aRecordingReport.value(0), aRecordingReportOld.value(0)));
                 ++iRowCount;
-                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording Attributes", "details (display/video capture)"),
+                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording Attributes", "details (display/recording)"),
                                                          empReport(aRecordingReport.value(1), aRecordingReportOld.value(1)));
             }
@@ -1386,6 +1386,6 @@
             {
                 ++iRowCount;
-                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording", "details (display/video capture)"),
-                                                         empReport(QApplication::translate("UIGDetails", "Disabled", "details (display/video capture)"), aRecordingReportOld.isEmpty()));
+                strItem += QString(sSectionItemTpl2).arg(QApplication::translate("UIGDetails", "Recording", "details (display/recording)"),
+                                                         empReport(QApplication::translate("UIGDetails", "Disabled", "details (display/recording)"), aRecordingReportOld.isEmpty()));
             }
 
@@ -1748,17 +1748,17 @@
     QStringList aReport;
     /* Acquire recording status: */
-    CCaptureSettings recordingSettings = comMachine.GetCaptureSettings();
+    CCaptureSettings comRecordingSettings = comMachine.GetCaptureSettings();
     /* For now all screens have the same config: */
-    CCaptureScreenSettings recordingScreen0Settings = recordingSettings.GetScreenSettings(0);
-    if (recordingScreen0Settings.GetEnabled())
-    {
-        /* Recording ile: */
-        aReport << recordingScreen0Settings.GetFileName();
+    CCaptureScreenSettings comRecordingScreen0Settings = comRecordingSettings.GetScreenSettings(0);
+    if (comRecordingScreen0Settings.GetEnabled())
+    {
+        /* Recording file: */
+        aReport << comRecordingScreen0Settings.GetFileName();
         /* Recording attributes: */
         aReport << QApplication::translate("UIGDetails", "Frame Size: %1x%2, Frame Rate: %3fps, Bit Rate: %4kbps")
-                                           .arg(recordingScreen0Settings.GetVideoWidth())
-                                           .arg(recordingScreen0Settings.GetVideoHeight())
-                                           .arg(recordingScreen0Settings.GetVideoFPS())
-                                           .arg(recordingScreen0Settings.GetVideoRate());
+                                           .arg(comRecordingScreen0Settings.GetVideoWidth())
+                                           .arg(comRecordingScreen0Settings.GetVideoHeight())
+                                           .arg(comRecordingScreen0Settings.GetVideoFPS())
+                                           .arg(comRecordingScreen0Settings.GetVideoRate());
     }
     /* Return report: */

Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.cpp	(revision 75318)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.cpp	(revision 75319)
@@ -813,5 +813,5 @@
         , m_pAnimation(0)
         , m_dRotationAngle(0)
-        , m_eRecordingMode(UIIndicatorStateRecordingMode_None)
+        , m_enmRecordingMode(UIIndicatorStateRecordingMode_None)
     {
         /* Assign state-icons: */
@@ -880,11 +880,11 @@
     {
         /* Get machine: */
-        const CMachine machine = m_pSession->machine();
+        const CMachine comMachine = m_pSession->machine();
         const bool fMachinePaused = m_pSession->isPaused();
 
         /* Update indicator state early: */
-        CCaptureSettings captureSettings = machine.GetCaptureSettings();
-        Assert(captureSettings.isOk());
-        if (!captureSettings.GetEnabled())
+        CCaptureSettings comRecordingSettings = comMachine.GetCaptureSettings();
+        Assert(comRecordingSettings.isOk());
+        if (!comRecordingSettings.GetEnabled())
             setState(UIIndicatorStateRecording_Disabled);
         else if (!fMachinePaused)
@@ -901,6 +901,6 @@
             case UIIndicatorStateRecording_Disabled:
             {
-                strFullData += s_strTableRow1 /** @todo r=andy Refine this tooltip (audio and/or video). */
-                    .arg(QApplication::translate("UIIndicatorsPool", "Video capture disabled", "Video capture tooltip"));
+                strFullData += s_strTableRow1
+                    .arg(QApplication::translate("UIIndicatorsPool", "Recording disabled", "Recording tooltip"));
                 break;
             }
@@ -909,19 +909,19 @@
             {
                 QString strToolTip;
-                if ( m_eRecordingMode & UIIndicatorStateRecordingMode_Audio &&
-                    m_eRecordingMode & UIIndicatorStateRecordingMode_Video)
-                    strToolTip = "Video/audio capture file";
-                else if (m_eRecordingMode & UIIndicatorStateRecordingMode_Audio)
-                    strToolTip = "Audio capture file";
-                else if (m_eRecordingMode & UIIndicatorStateRecordingMode_Video)
-                    strToolTip = "Video capture file";
+                if (   m_enmRecordingMode & UIIndicatorStateRecordingMode_Audio
+                    && m_enmRecordingMode & UIIndicatorStateRecordingMode_Video)
+                    strToolTip = QApplication::translate("UIIndicatorsPool", "Video/audio recording file", "Recording tooltip");
+                else if (m_enmRecordingMode & UIIndicatorStateRecordingMode_Audio)
+                    strToolTip = QApplication::translate("UIIndicatorsPool", "Audio recording file", "Recording tooltip");
+                else if (m_enmRecordingMode & UIIndicatorStateRecordingMode_Video)
+                    strToolTip = QApplication::translate("UIIndicatorsPool", "Video recording file", "Recording tooltip");
 
                 /* For now all screens have the same config: */
-                CCaptureScreenSettings captureScreen0Settings = captureSettings.GetScreenSettings(0);
-                Assert(captureScreen0Settings.isOk());
-
-                strFullData += s_strTableRow2 /** @todo r=andy Refine this tooltip (audio and/or video). */
-                    .arg(QApplication::translate("UIIndicatorsPool", strToolTip.toLatin1().constData(), "Video capture tooltip"))
-                    .arg(captureScreen0Settings.GetFileName());
+                CCaptureScreenSettings comRecordingScreen0Settings = comRecordingSettings.GetScreenSettings(0);
+                Assert(comRecordingScreen0Settings.isOk());
+
+                strFullData += s_strTableRow2
+                    .arg(strToolTip)
+                    .arg(comRecordingScreen0Settings.GetFileName());
                 break;
             }
@@ -943,24 +943,24 @@
     void setRotationAngle(double dRotationAngle) { m_dRotationAngle = dRotationAngle; update(); }
 
     /* Parses CaptureScreenSettings::Options and updates m_eRecordingMode accordingly. */
     void updateRecordingMode()
     {
-        m_eRecordingMode = UIIndicatorStateRecordingMode_None;
+        m_enmRecordingMode = UIIndicatorStateRecordingMode_None;
 
         /* Get machine: */
         if (!m_pSession)
             return;
-        const CMachine machine = m_pSession->machine();
-        if (machine.isNull())
+        const CMachine comMachine = m_pSession->machine();
+        if (comMachine.isNull())
             return;
 
-        CCaptureSettings recordingSettings = machine.GetCaptureSettings();
+        CCaptureSettings comRecordingSettings = comMachine.GetCaptureSettings();
         /* For now all screens have the same config: */
-        CCaptureScreenSettings recordingScreen0Settings = recordingSettings.GetScreenSettings(0);
+        CCaptureScreenSettings recordingScreen0Settings = comRecordingSettings.GetScreenSettings(0);
         if (recordingScreen0Settings.IsFeatureEnabled(KCaptureFeature_Video))
-            m_eRecordingMode = (UIIndicatorStateRecordingMode)((int)m_eRecordingMode | (int)UIIndicatorStateRecordingMode_Video);
+            m_enmRecordingMode = (UIIndicatorStateRecordingMode)((int)m_enmRecordingMode | (int)UIIndicatorStateRecordingMode_Video);
 
         if (recordingScreen0Settings.IsFeatureEnabled(KCaptureFeature_Audio))
-            m_eRecordingMode = (UIIndicatorStateRecordingMode)((int)m_eRecordingMode | (int)UIIndicatorStateRecordingMode_Audio);
+            m_enmRecordingMode = (UIIndicatorStateRecordingMode)((int)m_enmRecordingMode | (int)UIIndicatorStateRecordingMode_Audio);
     }
 
@@ -970,5 +970,6 @@
     double m_dRotationAngle;
 
-    UIIndicatorStateRecordingMode m_eRecordingMode;
+    /** Holds the recording mode. */
+    UIIndicatorStateRecordingMode m_enmRecordingMode;
 };
 
@@ -943,24 +943,24 @@
     void setRotationAngle(double dRotationAngle) { m_dRotationAngle = dRotationAngle; update(); }
 
-    /* Parses CaptureScreenSettings::Options and updates m_eRecordingMode accordingly. */
+    /* Parses CaptureScreenSettings::Options and updates m_enmRecordingMode accordingly. */
     void updateRecordingMode()
     {